==> packageinstaller-pkglist-libre_0.3.0.tar.xz: packageinstaller-pkglist-libre/Punjabi_LO_Latest_full.pm <==
<?xml version="1.0" encoding="UTF-8"?>
<app>

<category>
Language
</category>

<name>
Pujabi_LO_Latest_full
</name>

<description>
   <am>Punjabi Language Meta-Package for LibreOffice</am>
   <ar>Punjabi Language Meta-Package for LibreOffice</ar>
   <be>Punjabi Language Meta-Package for LibreOffice</be>
   <bg>Punjabi Language Meta-Package for LibreOffice</bg>
   <bn>Punjabi Language Meta-Package for LibreOffice</bn>
   <ca>Metapaquet d'idioma Punjabi per LibreOffice</ca>
   <cs>Punjabi Language Meta-Package for LibreOffice</cs>
   <da>Punjabi Language Meta-Package for LibreOffice</da>
   <de>Punjabi Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Punjabi</el>
   <en>Punjabi Language Meta-Package for LibreOffice</en>
   <es_ES>Meta-Paquete de idioma Punjabi para LibreOffice</es_ES>
   <es>Metapaquete de idioma Punjabi para LibreOffice</es>
   <et>Punjabi Language Meta-Package for LibreOffice</et>
   <eu>Punjabi Language Meta-Package for LibreOffice</eu>
   <fa>Punjabi Language Meta-Package for LibreOffice</fa>
   <fil_PH>Punjabi Language Meta-Package for LibreOffice</fil_PH>
   <fi>Punjabinkielinen kielipaketti LibreOffice:lle</fi>
   <fr_BE>Méta-Paquet en langue punjabi (Inde) pour LibreOffice</fr_BE>
   <fr>Méta-Paquet en langue punjabi (Inde) pour LibreOffice</fr>
   <gl_ES>Panjabi Meta-paquete de Idioma para LibreOffice</gl_ES>
   <gu>Punjabi Language Meta-Package for LibreOffice</gu>
   <he_IL>Punjabi Language Meta-Package for LibreOffice</he_IL>
   <hi>लिब्रे-ऑफिस हेतु पंजाबी भाषा मेटा-पैकेज</hi>
   <hr>Punjabi Language Meta-Package for LibreOffice</hr>
   <hu>Punjabi Language Meta-Package for LibreOffice</hu>
   <id>Punjabi Language Meta-Package for LibreOffice</id>
   <is>Punjabi Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua punjabi per LibreOffice</it>
   <ja>LibreOffice用パンジャーブ語メタパッケージ</ja>
   <kk>Punjabi Language Meta-Package for LibreOffice</kk>
   <ko>Punjabi Language Meta-Package for LibreOffice</ko>
   <ku>Punjabi Language Meta-Package for LibreOffice</ku>
   <lt>Punjabi Language Meta-Package for LibreOffice</lt>
   <mk>Punjabi Language Meta-Package for LibreOffice</mk>
   <mr>Punjabi Language Meta-Package for LibreOffice</mr>
   <nb_NO>Punjabi Language Meta-Package for LibreOffice</nb_NO>
   <nb>Punjabi språkpakke for LibreOffice</nb>
   <nl_BE>Punjabi Language Meta-Package for LibreOffice</nl_BE>
   <nl>Punjabi Taal Meta-Pakket voor LibreOffice</nl>
   <or>Punjabi Language Meta-Package for LibreOffice</or>
   <pl>Meta-pakiet języka Punjabi dla LibreOffice</pl>
   <pt_BR>Punjabi Pacote de Idioma para o LibreOffice</pt_BR>
   <pt>Panjabi Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>Punjabi Language Meta-Package for LibreOffice</ro>
   <ru>Punjabi Language Meta-Package for LibreOffice</ru>
   <sk>Punjabi Language Meta-Package for LibreOffice</sk>
   <sl>Pundžabski jezikovni meta-paket za LibreOffice</sl>
   <so>Punjabi Language Meta-Package for LibreOffice</so>
   <sq>Meta-Paketë gjuhësore për LibreOffice-in në panxhabisht</sq>
   <sr>Punjabi Language Meta-Package for LibreOffice</sr>
   <sv>Punjabi Språk Meta-Paket för LibreOffice</sv>
   <th>Meta-Package ภาษา Punjabi สำหรับ LibreOffice</th>
   <tr>LibreOffice için Pencap Dili Üst-Paketi</tr>
   <uk>Punjabi Language Meta-Package for LibreOffice</uk>
   <vi>Punjabi Language Meta-Package for LibreOffice</vi>
   <zh_CN>Punjabi Language Meta-Package for LibreOffice</zh_CN>
   <zh_HK>Punjabi Language Meta-Package for LibreOffice</zh_HK>
   <zh_TW>Punjabi Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
echo "deb http://deb.debian.org/debian bullseye-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
apt-get update
</preinstall>

<install_package_names>
-t bullseye-backports libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-gtk3
libreoffice-l10n-pa-in
libreoffice-java-common
</install_package_names>

<postinstall>
rm /etc/apt/sources.list.d/pitemp.list
apt-get update
</postinstall>

<uninstall_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-java-common
libreoffice-gtk3
libreoffice-l10n-pa-in
</uninstall_package_names>

</app>

==> packageinstaller-pkglist-libre_0.4.0.tar.xz: packageinstaller-pkglist-libre/Punjabi_LO_Latest_full.pm <==
<?xml version="1.0" encoding="UTF-8"?>
<app>

<category>
Language
</category>

<name>
Pujabi_LO_Latest_full
</name>

<description>
   <am>Punjabi Language Meta-Package for LibreOffice</am>
   <ar>Punjabi Language Meta-Package for LibreOffice</ar>
   <be>Punjabi Language Meta-Package for LibreOffice</be>
   <bg>Punjabi Language Meta-Package for LibreOffice</bg>
   <bn>Punjabi Language Meta-Package for LibreOffice</bn>
   <ca>Metapaquet d'idioma Punjabi per LibreOffice</ca>
   <cs>Punjabi Language Meta-Package for LibreOffice</cs>
   <da>Punjabi Language Meta-Package for LibreOffice</da>
   <de>Punjabi Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Punjabi</el>
   <en>Punjabi Language Meta-Package for LibreOffice</en>
   <es_ES>Meta-Paquete de idioma Punjabi para LibreOffice</es_ES>
   <es>Metapaquete de idioma Punjabi para LibreOffice</es>
   <et>Punjabi Language Meta-Package for LibreOffice</et>
   <eu>Punjabi Language Meta-Package for LibreOffice</eu>
   <fa>Punjabi Language Meta-Package for LibreOffice</fa>
   <fil_PH>Punjabi Language Meta-Package for LibreOffice</fil_PH>
   <fi>Punjabinkielinen kielipaketti LibreOffice:lle</fi>
   <fr_BE>Méta-Paquet en langue punjabi (Inde) pour LibreOffice</fr_BE>
   <fr>Méta-Paquet en langue punjabi (Inde) pour LibreOffice</fr>
   <gl_ES>Panjabi Meta-paquete de Idioma para LibreOffice</gl_ES>
   <gu>Punjabi Language Meta-Package for LibreOffice</gu>
   <he_IL>Punjabi Language Meta-Package for LibreOffice</he_IL>
   <hi>लिब्रे-ऑफिस हेतु पंजाबी भाषा मेटा-पैकेज</hi>
   <hr>Punjabi Language Meta-Package for LibreOffice</hr>
   <hu>Punjabi Language Meta-Package for LibreOffice</hu>
   <id>Punjabi Language Meta-Package for LibreOffice</id>
   <is>Punjabi Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua punjabi per LibreOffice</it>
   <ja>LibreOffice用パンジャーブ語メタパッケージ</ja>
   <kk>Punjabi Language Meta-Package for LibreOffice</kk>
   <ko>Punjabi Language Meta-Package for LibreOffice</ko>
   <ku>Punjabi Language Meta-Package for LibreOffice</ku>
   <lt>Punjabi Language Meta-Package for LibreOffice</lt>
   <mk>Punjabi Language Meta-Package for LibreOffice</mk>
   <mr>Punjabi Language Meta-Package for LibreOffice</mr>
   <nb_NO>Punjabi Language Meta-Package for LibreOffice</nb_NO>
   <nb>Punjabi språkpakke for LibreOffice</nb>
   <nl_BE>Punjabi Language Meta-Package for LibreOffice</nl_BE>
   <nl>Punjabi Taal Meta-Pakket voor LibreOffice</nl>
   <or>Punjabi Language Meta-Package for LibreOffice</or>
   <pl>Meta-pakiet języka Punjabi dla LibreOffice</pl>
   <pt_BR>Punjabi Pacote de Idioma para o LibreOffice</pt_BR>
   <pt>Panjabi Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>Punjabi Language Meta-Package for LibreOffice</ro>
   <ru>Punjabi Language Meta-Package for LibreOffice</ru>
   <sk>Punjabi Language Meta-Package for LibreOffice</sk>
   <sl>Pundžabski jezikovni meta-paket za LibreOffice</sl>
   <so>Punjabi Language Meta-Package for LibreOffice</so>
   <sq>Meta-Paketë gjuhësore për LibreOffice-in në panxhabisht</sq>
   <sr>Punjabi Language Meta-Package for LibreOffice</sr>
   <sv>Punjabi Språk Meta-Paket för LibreOffice</sv>
   <th>Meta-Package ภาษา Punjabi สำหรับ LibreOffice</th>
   <tr>LibreOffice için Pencap Dili Üst-Paketi</tr>
   <uk>Punjabi Language Meta-Package for LibreOffice</uk>
   <vi>Punjabi Language Meta-Package for LibreOffice</vi>
   <zh_CN>Punjabi Language Meta-Package for LibreOffice</zh_CN>
   <zh_HK>Punjabi Language Meta-Package for LibreOffice</zh_HK>
   <zh_TW>Punjabi Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
-t bookworm-backports libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-gtk3
libreoffice-l10n-pa-in
libreoffice-java-common
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-java-common
libreoffice-gtk3
libreoffice-l10n-pa-in
</uninstall_package_names>

</app>
